package com.ym.mec.auth.web.controller;

import com.ym.mec.auth.api.entity.SysMenu;
import com.ym.mec.auth.service.SysMenuService;
import com.ym.mec.common.controller.BaseController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

@RestController()
@RequestMapping("menu")
@Api(tags = "菜单服务")
public class MenuController extends BaseController {

    @Autowired
    private SysMenuService sysMenuService;

    @ApiOperation("新增菜单")
    @PutMapping("/add")
    public Object getMenu(SysMenu sysMenu) {
        SysMenu menuByPermission = sysMenuService.findMenuByPermission(sysMenu.getPermission());
        if(menuByPermission != null){
            return failed("权限标识不能重复");
        }
        Date date = new Date();
        sysMenu.setUpdateTime(date);
        sysMenu.setCreateTime(date);
        return succeed(sysMenuService.insert(sysMenu));
    }

    @ApiOperation("根据菜单id删除菜单")
    @DeleteMapping("/del/{id}")
    public Object delMenu(@ApiParam(value = "菜单编号", required = true) @PathVariable("id") Integer id) {
        return succeed(sysMenuService.delete(id));
    }

    @ApiOperation("根据菜单id修改菜单")
    @PutMapping("/update")
    public Object updateMenu(SysMenu sysMenu) {
        SysMenu menuByPermission = sysMenuService.findMenuByPermission(sysMenu.getPermission());
        if(menuByPermission != null && !menuByPermission.getId().equals(sysMenu.getId())){
            return failed("权限标识不能重复");
        }
        Date date = new Date();
        sysMenu.setUpdateTime(date);
        return succeed(sysMenuService.update(sysMenu));
    }

    @ApiOperation("根据菜单id查询菜单")
    @GetMapping("/{id}")
    public Object getMenu(@ApiParam(value = "菜单编号", required = true) @PathVariable("id") Integer id) {
        return succeed(sysMenuService.get(id));
    }

    @ApiOperation("根据用户编号查询用户可访问菜单")
    @GetMapping("/findByUser/{id}")
    public Object findByUser(@ApiParam(value = "用户编号", required = true) @PathVariable("id") Integer id) {
        return succeed(sysMenuService.findByUser(id));
    }



}
