package com.ym.mec.web.controller;

import com.ym.mec.common.controller.BaseController;
import com.ym.mec.web.dal.entity.Subject;
import com.ym.mec.web.dal.page.SubjectQueryInfo;
import com.ym.mec.web.service.SubjectService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

@RequestMapping("subject")
@Api(tags = "科目服务")
@RestController
public class SubjectController extends BaseController {

    @Autowired
    private SubjectService subjectService;

    @ApiOperation(value = "新增科目")
    @PostMapping("/add")
    public Object add(Subject subject){
        Date date = new Date();
        subject.setCreateTime(date);
        subject.setUpdateTime(date);
        subjectService.insert(subject);
        return succeed();
    }

    @ApiOperation(value = "删除科目")
    @DeleteMapping("/del/{id}")
    public Object del(@ApiParam(value = "科目编号", required = true) @PathVariable("id") Integer id){
        subjectService.delete(id);
        return succeed();
    }

    @ApiOperation(value = "修改科目")
    @PutMapping("/update")
    public Object update(Subject subject){
        subject.setUpdateTime(new Date());
        subjectService.update(subject);
        return succeed();
    }

    @ApiOperation(value = "根据科目编号查询科目")
    @GetMapping("/get/{id}")
    public Object get(@ApiParam(value = "科目编号", required = true) @PathVariable("id") Integer id){
        return succeed(subjectService.get(id));
    }

    @ApiOperation(value = "分页查询科目列表")
    @PostMapping("/queryPage")
    public Object queryPage(SubjectQueryInfo queryInfo){
        return succeed(subjectService.queryPage(queryInfo));
    }

    @ApiOperation(value = "通过乐团编号查询科目列表")
    @PostMapping("/querySubByMusicGroupId")
    @ApiImplicitParams({ @ApiImplicitParam(name = "musicGroupId", value = "乐团编号", required = true, dataType = "Integer")})
    public Object findSubByMusicGroupId(Integer musicGroupId){
        return succeed(subjectService.findSubByMusicGroupId(musicGroupId));
    }

    @ApiOperation(value = "通过乐团收费类型，获取默认的声部列表")
    @PostMapping("/findSubByChargeType")
    @ApiImplicitParams({ @ApiImplicitParam(name = "chargeTypeId", value = "收费类型编号", required = true, dataType = "Integer")})
    public Object findSubByChargeType(Integer chargeTypeId){
        return succeed(subjectService.findSubByChargeType(chargeTypeId));
    }
}
