package com.ym.mec.web.controller;

import com.ym.mec.common.controller.BaseController;
import com.ym.mec.web.dal.entity.Teacher;
import com.ym.mec.web.dal.page.TeacherQueryInfo;
import com.ym.mec.web.service.TeacherService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import java.util.Date;

@RequestMapping("teacher")
@Api(tags = "教师服务")
@RestController
public class TeacherController extends BaseController {

    @Autowired
    private TeacherService teacherService;

    @ApiOperation(value = "新增教师")
    @PostMapping("/add")
    public Object add(Teacher teacher){
        Date date = new Date();
        teacher.setCreateTime(date);
        teacher.setUpdateTime(date);
        teacherService.insert(teacher);
        return succeed();
    }

    @ApiOperation(value = "删除教师")
    @DeleteMapping("/del/{id}")
    public Object del(@ApiParam(value = "教师编号", required = true) @PathVariable("id") Integer id){
        teacherService.delete(id);
        return succeed();
    }

    @ApiOperation(value = "修改教师")
    @PutMapping("/update")
    public Object update(Teacher teacher){
        teacher.setUpdateTime(new Date());
        teacherService.update(teacher);
        return succeed();
    }

    @ApiOperation(value = "根据教师编号查询教师")
    @GetMapping("/get/{id}")
    public Object get(@ApiParam(value = "教师编号", required = true) @PathVariable("id") Integer id){
        return succeed(teacherService.get(id));
    }

    @ApiOperation(value = "分页查询教师列表")
    @PostMapping("/queryPage")
    public Object queryPage(TeacherQueryInfo queryInfo){
        return succeed(teacherService.queryPage(queryInfo));
    }
}
